"""Tests for the trustymail module."""
# Standard Python Libraries
import unittest


class TestLiveliness(unittest.TestCase):
    """Test the liveliness of a domain."""

    def test_domain_list_parsing(self):
        """Test that a domain list is correctly parsed."""
        pass
